@@ -3,8 +3,8 @@ package Test::Compile::Internal;
 use warnings;
 use strict;
 
-use version; our $VERSION = version->declare("v3.1.1");
-use File::Spec;
+use version; our $VERSION = version->declare("v3.2.0");
+use File::Find;
 use Test::Builder;
 use IPC::Open3 ();
 
@@ -149,9 +149,6 @@ if that directory exists, otherwise it'll search the F<lib> directory.
 
 Skips any files in F<CVS>, F<.svn>, or F<.git> directories.
 
-The order of the files returned is machine-dependent. If you want them
-sorted, you'll have to sort them yourself.
-
 =cut
 
 sub all_pm_files {
@@ -182,9 +179,6 @@ and F<bin/> directories
 
 Skips any files in F<CVS>, F<.svn>, or F<.git> directories.
 
-The order of the files returned is machine-dependent. If you want them
-sorted, you'll have to sort them yourself.
-
 =cut
 
 sub all_pl_files {
@@ -333,28 +327,19 @@ sub _run_command {
 sub _find_files {
     my ($self, @searchlist) = @_;
 
-    my @output;
-    for my $file (@searchlist) {
-        if (defined($file) && -f $file) {
-            push @output, $file;
-        } elsif (defined($file) && -d $file) {
-            local *DH;
-            opendir DH, $file or next;
-            my @newfiles = readdir DH;
-            closedir DH;
-            @newfiles = File::Spec->no_upwards(@newfiles);
-            @newfiles = grep { $_ ne "CVS" && $_ ne ".svn" && $_ ne ".git" } @newfiles;
-            for my $newfile (@newfiles) {
-                my $filename = File::Spec->catfile($file, $newfile);
-                if (-f $filename) {
-                    push @output, $filename;
-                } else {
-                    push @searchlist, File::Spec->catdir($file, $newfile);
-                }
+    my @filelist;
+    my $findfunc = sub {
+        my $fname = $File::Find::name;
+        if ( -f $fname ) {
+            if ( !($fname =~ m/CVS|\.svn|\.git/) ) {
+                push @filelist, $fname;
             }
         }
-    }
-    return @output;
+    };
+
+    no warnings 'File::Find';
+    find({wanted => $findfunc, no_chdir => 1}, @searchlist);
+    return (sort @filelist);
 }
 
 # Check the syntax of a perl file
@@ -366,7 +351,7 @@ sub _perl_file_compiles {
         return 0;
     }
 
-    my @inc = ('blib/lib', @INC);
+    my @inc = (File::Spec->catdir("blib", "lib"), @INC);
     my $taint = $self->_taint_mode($file);
     my $command = join(" ", (qq{"$^X"}, (map { qq{"-I$_"} } @inc), "-c$taint", $file));
     if ( $self->verbose() ) {
@@ -391,8 +376,9 @@ sub _default_locations {
     my @locations = ();
     my $prefix = -e 'blib' ? "blib" : ".";
     for my $dir ( @dirs ) {
-	if ( -e "$prefix/$dir" ) {
-            push @locations, "$prefix/$dir";
+        my $location = File::Spec->catfile($prefix, $dir);
+	if ( -e $location ) {
+            push @locations, $location;
         }
     }
     return @locations;
